# -- coding: utf-8 --
"""Script usado para calcular a inclinação das retas de aproximação de cada uma
das séries temporais extraídas.
"""

from __future__ import division

import sys
from datetime import date
import numpy as np
import matplotlib.pyplot as plt

from parser import StpyParser
from settings import *


def real_values (ht, hb):
    if ht == CALC_HT_FAKE and hb == CALC_HB_FAKE:
        s = "Invalid hemtocrit and hemoglobin values. Abort!"
        sys.exit(s)
    real_ht = (3*hb) if (ht == CALC_HT_FAKE) else ht
    real_hb = (ht/3) if (hb == CALC_HB_FAKE) else hb
    return (real_ht, real_hb)


parser = StpyParser(EXT_OUTPUT_FILE)

start_day = parser.meta['start_date']
end_day = parser.meta['end_date']
num_donators = parser.meta['num_donators']

alphas = []
i = 1
for donator in parser.donators():
    dates = []
    metric = []
    for donation in donator.donations:
        date_offset, ht, hb = donation
        dates.append(date_offset)
        ht, hb = real_values(ht, hb)
        v = ht if CALC_HT_METRIC else hb
        metric.append(v)

    x = np.array(dates)
    y = np.array(metric)

    pol = np.polyfit(x, y, 1)
    alphas.append(pol[0])

    # progress logging
    progress_str = '\r' + str(i) + " / " + str(num_donators)
    sys.stdout.write(progress_str)
    sys.stdout.flush()
    i += 1
sys.stdout.write('\n')

f = open(CALC_OUTPUT_FILE, 'w')
s = ""
for a in alphas:
    s += str(a) + '\n'
f.write(s)
